# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"image_box": "box.ipynb",
         "get_array": "box.ipynb",
         "cat_box": "box.ipynb",
         "mcat_box": "box.ipynb",
         "bbox_box": "box.ipynb",
         "DataBox": "core.ipynb",
         "create_datablock": "core.ipynb",
         "create_dataloaders": "core.ipynb",
         "dataloaders_seed": "core.ipynb",
         "function": "utils.ipynb",
         "T": "utils.ipynb",
         "identity": "utils.ipynb",
         "simplify": "utils.ipynb",
         "listify": "utils.ipynb",
         "setify": "utils.ipynb",
         "tuplify": "utils.ipynb",
         "merge_tfms": "utils.ipynb",
         "compose": "utils.ipynb",
         "pipe": "utils.ipynb",
         "flow": "utils.ipynb",
         "get_files": "utils.ipynb",
         "Path.find": "utils.ipynb",
         "Path.decompress": "utils.ipynb",
         "Path.compress": "utils.ipynb",
         "Path.download": "utils.ipynb",
         "save_array": "utils.ipynb"}

modules = ["box.py",
           "core.py",
           "utils.py"]

doc_url = "//"

git_url = "https://github.com/limiteinductive/Databox/tree/main/"

def custom_doc_links(name): return None
